@@ -38,7 +38,8 @@ const routes: Routes = [{
     data: [{
         schema: 'config',
         table: 'hard_due_date',
-        fieldOrder: 'name,owner,ceiling_date,forceto'
+        fieldOrder: 'name,owner,ceiling_date,forceto',
+        orgFieldsDefaultingToContextOrg: 'owner'
     }]
 }, {
     path: 'config/print_template',
@@ -128,6 +129,13 @@ const routes: Routes = [{
     component: BasicAdminPageComponent,
     data: [{schema: 'sip',
         table: 'filter', readonlyFields: 'key'}]
+}, {
+    path: 'config/kpac_topics',
+    component: BasicAdminPageComponent,
+    data: [{schema: 'config',
+        table: 'kpac_topics',
+        readonlyFields: 'id',
+        fieldOrder: 'name,description,active,img,id,parent,topic_order,content_type,content_list,content_search, content_link'}]
 }, {
     path: ':schema/:table',
     component: BasicAdminPageComponent
