@@ -1,7 +1,6 @@
 /* eslint-disable max-len, no-prototype-builtins */
 import {Injectable, EventEmitter, OnDestroy} from '@angular/core';
-import {Subject} from 'rxjs';
-import {tap, takeUntil} from 'rxjs/operators';
+import {Subject, tap, takeUntil, toArray, lastValueFrom, Observable, Subscription} from 'rxjs';
 import {SafeUrl} from '@angular/platform-browser';
 import {IdlService, IdlObject} from '@eg/core/idl.service';
 import {NetService} from '@eg/core/net.service';
@@ -499,17 +498,17 @@ export class VolCopyService implements OnDestroy {
             'eg.cat.volcopy.defaults', this.defaults);
     }
 
-    fetchBibParts(recordIds: number[]) {
+    fetchBibParts(recordIds: number[]) : Promise<any> {
 
         if (recordIds.length === 0) { return; }
 
         // All calls fetch updated data since we may be creating
         // new mono parts during editing.
 
-        this.pcrud.search('bmp',
+        return lastValueFrom( this.pcrud.search('bmp',
             {record: recordIds, deleted: 'f'})
-            .subscribe(
-                part => {
+            .pipe(tap({
+                next: part => {
                     const updatedBibParts =  {...this.bibParts};
                     if (!updatedBibParts[part.record()]) {
                         updatedBibParts[part.record()] = [];
@@ -519,8 +518,8 @@ export class VolCopyService implements OnDestroy {
                     }
                     this.bibParts = updatedBibParts;
                 },
-                (err: unknown) => {},
-                () => {
+                error: (err: unknown) => {},
+                complete: () => {
                     const finalBibParts = {...this.bibParts};
                     recordIds.forEach(bibId => {
                         if (finalBibParts[bibId]) {
@@ -531,7 +530,8 @@ export class VolCopyService implements OnDestroy {
                     });
                     this.bibParts = finalBibParts;
                 }
-            );
+            }), toArray())
+        );
     }
 
 
@@ -604,8 +604,7 @@ export class VolCopyService implements OnDestroy {
                         // convert actual booleans to 't' and 'f'
                         Object.keys(data).forEach(key => {
                             if (this.idl.classes.acp.field_map[key]?.datatype === 'bool') {
-                                if (data[key] === true) { data[key] = 't'; }
-                                else if (data[key] === false) { data[key] = 'f'; }
+                                if (data[key] === true) { data[key] = 't'; } else if (data[key] === false) { data[key] = 'f'; }
                             }
                         });
 
@@ -616,8 +615,7 @@ export class VolCopyService implements OnDestroy {
                                 data[thing].forEach(thingElement => {
                                     Object.keys(thingElement).forEach(key => {
                                         if (this.idl.classes[ant[thing]].field_map[key].datatype === 'bool') {
-                                            if (thingElement[key] === true) { thingElement[key] = 't'; }
-                                            else if (thingElement[key] === false) { thingElement[key] = 'f'; }
+                                            if (thingElement[key] === true) { thingElement[key] = 't'; } else if (thingElement[key] === false) { thingElement[key] = 'f'; }
                                         }
                                     });
                                 });
