@@ -1,6 +1,5 @@
 import {Component, OnDestroy, OnInit, ViewChild} from '@angular/core';
-import {Router, ActivatedRoute, ParamMap} from '@angular/router';
-import {EventService} from '@eg/core/event.service';
+import {ActivatedRoute, ParamMap} from '@angular/router';
 import {NetService} from '@eg/core/net.service';
 import {AuthService} from '@eg/core/auth.service';
 import {PcrudService} from '@eg/core/pcrud.service';
@@ -8,7 +7,7 @@ import {PermService} from '@eg/core/perm.service';
 import {IdlObject} from '@eg/core/idl.service';
 import {OrgService} from '@eg/core/org.service';
 import {ServerStoreService} from '@eg/core/server-store.service';
-import {BibRecordService, BibRecordSummary} from '@eg/share/catalog/bib-record.service';
+import {BibRecordSummary} from '@eg/share/catalog/bib-record.service';
 import {CatalogService} from '@eg/share/catalog/catalog.service';
 import {StaffCatalogService} from '../catalog.service';
 import {HoldsService, HoldRequest,
@@ -23,7 +22,61 @@ import {BarcodeSelectComponent
 import {WorkLogService} from '@eg/staff/share/worklog/worklog.service';
 import {getI18nString} from '@eg/share/util/i18ns';
 import {StoreService} from '@eg/core/store.service';
-import {firstValueFrom} from 'rxjs';
+import {firstValueFrom, lastValueFrom, tap, toArray} from 'rxjs';
+
+export class HoldRequestStats {
+    private successes = 0;
+    private attempts = 0;
+    private failureCodes: Set<string> = new Set();
+
+    public addSuccess(): void {
+        this.successes++;
+        this.attempts++;
+    }
+    public addFailure(failureCode: string): void {
+        this.attempts++;
+        this.failureCodes.add(failureCode);
+    }
+    public reset(): void {
+        this.successes = 0;
+        this.attempts = 0;
+    }
+    public summary():
+        {overall: 'AllHoldsPlaced'} |
+        {overall: 'SomeHoldsPlaced', successes: number, attempts: number, failures: number} |
+        {overall: 'NoHoldsPlaced', failureCodes: Set<string>} |
+        {overall: 'NoHoldsAttempted'} {
+        if (this.attempts === 0) {
+            return {overall: 'NoHoldsAttempted'};
+        } else if (this.successes === this.attempts) {
+            return {overall: 'AllHoldsPlaced'};
+        } else if (this.successes === 0) {
+            return {overall: 'NoHoldsPlaced', failureCodes: this.failureCodes};
+        } else {
+            return {
+                overall: 'SomeHoldsPlaced',
+                successes: this.successCount(),
+                attempts: this.attemptCount(),
+                failures: this.failureCount()
+            };
+        }
+    }
+    private successCount(): number {
+        return this.includesSummary() ? this.successes - 1 : this.successes;
+    }
+    private attemptCount(): number {
+        return this.includesSummary() ? this.attempts - 1 : this.attempts;
+    }
+    private failureCount(): number {
+        return this.attempts-this.successes;
+    }
+
+    // Do the stats include a "Summary" message from the backend that should be removed
+    // from the counts?
+    private includesSummary() {
+        return this.attempts > 1;
+    }
+}
 
 class HoldContext {
     holdMeta: HoldRequestTarget;
@@ -32,6 +85,7 @@ class HoldContext {
     canOverride?: boolean;
     processing: boolean;
     selectedFormats: any;
+    stats = new HoldRequestStats;
     success = false;
 
     constructor(target: number) {
@@ -61,7 +115,7 @@ export class HoldComponent implements OnInit, OnDestroy {
     user: IdlObject; //
     userBarcode: string;
     requestor: IdlObject;
-    holdFor: string;
+    holdFor: 'patron'|'staff'|'group';
     pickupLib: number;
     notifyEmail: boolean;
     notifyPhone: boolean;
@@ -82,6 +136,10 @@ export class HoldComponent implements OnInit, OnDestroy {
     smsCarriers: ComboboxEntry[];
     userBarcodeTimeout: any;
 
+    holdGroups: IdlObject[];
+    selectedHoldGroup: ComboboxEntry;
+    holdGroupsOverrideAllPossible = true;
+
     smsEnabled: boolean;
 
     maxMultiHolds = 0;
@@ -114,15 +172,12 @@ export class HoldComponent implements OnInit, OnDestroy {
     @ViewChild('activeDateAlert') private activeDateAlert: AlertDialogComponent;
 
     constructor(
-        private router: Router,
         private route: ActivatedRoute,
-        private evt: EventService,
         private net: NetService,
         private org: OrgService,
         private store: ServerStoreService,
         private auth: AuthService,
         private pcrud: PcrudService,
-        private bib: BibRecordService,
         private cat: CatalogService,
         private staffCat: StaffCatalogService,
         private holds: HoldsService,
@@ -219,6 +274,8 @@ export class HoldComponent implements OnInit, OnDestroy {
             const node = document.getElementById('patron-barcode');
             if (node) { node.focus(); }
         });
+
+        this.fetchHoldGroups();
     }
 
     getRequestorSetsAndPerms(): Promise<any> {
@@ -268,15 +325,13 @@ export class HoldComponent implements OnInit, OnDestroy {
         return new Promise(resolve => {
             this.holds.getHoldTargetMeta(this.holdType, this.holdTargets, this.auth.user().ws_ou())
                 .subscribe(
-                    meta => {
+                    { next: meta => {
                         this.holdContexts.filter(ctx => ctx.holdTarget === meta.target)
                             .forEach(ctx => {
                                 ctx.holdMeta = meta;
                                 this.mrFiltersToSelectors(ctx);
                             });
-                    },
-                    (err: unknown) => {},
-                    () => resolve(null)
+                    }, error: (err: unknown) => {}, complete: () => resolve(null) }
                 );
         });
     }
@@ -357,7 +412,7 @@ export class HoldComponent implements OnInit, OnDestroy {
             if (this.userBarcode) {
                 this.userBarcodeChanged();
             }
-        } else {
+        } else if (this.holdFor === 'staff') {
             this.userBarcode = null;
             this.currentUserBarcode = null;
             this.getUser(this.requestor.id());
@@ -561,12 +616,18 @@ export class HoldComponent implements OnInit, OnDestroy {
     }
 
     readyToPlaceHolds(): boolean {
-        if (!this.user || this.placeHoldsClicked || this.activeDateInvalid) {
+        if (this.placeHoldsClicked || this.activeDateInvalid) {
             return false;
         }
         if (!this.pickupLib || this.disableOrgs.includes(this.pickupLib)) {
             return false;
         }
+        if (this.holdFor === 'patron' && !this.user) {
+            return false;
+        }
+        if (this.holdFor === 'group' && !this.selectedHoldGroup) {
+            return false;
+        }
         if (this.smsEnabled && this.notifySms) {
             if (!this.smsValue.length || !this.smsCbox?.selectedId) {
                 return false;
@@ -637,6 +698,11 @@ export class HoldComponent implements OnInit, OnDestroy {
             return Promise.resolve();
         }
 
+        if (this.holdFor === 'group' && this.selectedHoldGroup && this.holdGroupsOverrideAllPossible) {
+            override = true;
+        }
+
+        ctx.stats.reset();
         ctx.processing = true;
         const selectedFormats = this.mrSelectorsToFilters(ctx);
 
@@ -657,10 +723,10 @@ export class HoldComponent implements OnInit, OnDestroy {
 
         console.debug(`Placing ${hType}-type hold on ${hTarget}`);
 
-        return this.holds.placeHold({
+        return lastValueFrom(this.holds.placeHold({
             holdTarget: hTarget,
             holdType: hType,
-            recipient: this.user.id(),
+            recipient: this.user?.id(),
             requestor: this.requestor.id(),
             pickupLib: this.pickupLib,
             override: override,
@@ -669,10 +735,18 @@ export class HoldComponent implements OnInit, OnDestroy {
             notifySms: this.smsEnabled && this.notifySms ? this.smsValue : null,
             smsCarrier: this.smsCbox ? this.smsCbox.selectedId : null,
             thawDate: this.suspend ? this.activeDateStr : null,
+            holdGroup: Boolean(this.holdFor === 'group' && this.selectedHoldGroup),
+            holdGroupId: (this.holdFor === 'group' && this.selectedHoldGroup) ? this.selectedHoldGroup.id : null,
             frozen: this.suspend,
             holdableFormats: selectedFormats
 
-        }).toPromise().then(
+        }).pipe(tap((request) => {
+            if (request.result.success) {
+                ctx.stats.addSuccess();
+            } else {
+                ctx.stats.addFailure(request.result?.evt?.textcode);
+            }
+        }))).then(
             request => {
                 ctx.lastRequest = request;
                 ctx.processing = false;
@@ -843,6 +917,23 @@ export class HoldComponent implements OnInit, OnDestroy {
             window.removeEventListener('focus', this.refreshRecentPatronIds);
         }
     }
+
+    get holdGroupsAsComboboxEntries(): ComboboxEntry[] {
+        return this.holdGroups.map(group => {
+            return {
+                id: group.id(),
+                label: group.name(),
+                fm: group
+            };
+        });
+    }
+
+    private fetchHoldGroups() {
+        this.pcrud.search('cub', {btype: 'hold_subscription'}, {order_by: {cub: 'name'}}).pipe(
+            toArray()
+        ).subscribe(arr => {this.holdGroups = arr;});
+    }
+
 }
 
 
