@@ -644,6 +644,7 @@ INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VAL
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '611', 'oc-FR', 'Braille');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '611', 'oc-FR', 'Braille');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '908', 'oc-FR', 'Braille');
+INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '1792', 'oc-FR', 'Braille');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '529', 'oc-FR', 'Electronic');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '712', 'oc-FR', 'Electronic');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '712', 'oc-FR', 'Electronic');
@@ -691,5 +692,7 @@ INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VAL
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1308', 'oc-FR', 'Samoan');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1323', 'oc-FR', 'Macedonian');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1331', 'oc-FR', 'Eslovèn');
+INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '1787', 'oc-FR', 'Lengas dels signes');
+INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1792', 'oc-FR', 'Braille');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aiit.name', 'TAX', 'oc-FR', 'Impòstes e taxas');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aiit.name', 'HND', 'oc-FR', 'Fraisses de manutencion');
